@@ -15,7 +15,10 @@ import sys, getopt
 #from oauthlib.oauth2 import BackendApplicationClient
 
 from inforion.ionapi.basic import load_config,login,header
-from inforion.ionapi.MMS import AddItmBasic,MMS021,MMS021bulk,MMS021bulk2,execute,executeSnd,executeAsyncSnd
+#from inforion.ionapi.MMS import AddItmBasic,MMS021,MMS021bulk,MMS021bulk2,execute,executeSnd,executeAsyncSnd
+from inforion.ionapi.controller import *
+from inforion.ionapi.model import * 
+
 
 from inforion.helper.urlsplit import spliturl
 def main():
@@ -109,46 +112,6 @@ def main():
             return "InforION Login is working"
     
     
-    '''
-    elif method == "MMS200MI":
-        config = load_config(ionfile)
-        token=login(url,config)
-        headers = header(config,token)
-        return AddItmBasic(url,headers,inputfile,'out.xslx')
-    elif method == "MMS021":
-        config = load_config(ionfile)
-        token=login(url,config)
-        headers = header(config,token)
-        return MMS021(url,headers,inputfile,'out.xslx')
-    elif method == "MMS021bulk":
-        config = load_config(ionfile)
-        token=login(url,config)
-        headers = header(config,token)
-        return MMS021bulk(url,headers,inputfile,'out.xslx')
-    elif method == "MMS021bulk2":
-        config = load_config(ionfile)
-        token=login(url,config)
-        headers = header(config,token)
-        return MMS021bulk2(url,headers,inputfile,'out.xslx')
-    elif method == "CRS610bulk":
-        config = load_config(ionfile)
-        token=login(url,config)
-        headers = header(config,token)
-        return CRS610bulk(url,headers,inputfile,'CRS610MI',outputfile,start,end)
-    elif method == "CRS610bulk2":
-        config = load_config(ionfile)
-        token=login(url,config)
-        headers = header(config,token)
-        return CRS610bulk2(url,headers,inputfile,'CRS610MI',outputfile)
-    elif method == "CRS610":
-        config = load_config(ionfile)
-        token=login(url,config)
-        headers = header(config,token)
-        return CRS610(url,headers,inputfile,'out.xslx')
-    
-    else:
-        return ('Sorry you need to define a method plese use inforion -h')
-    '''
 
 if __name__ == "__main__":
     #sys.exit(run("-h"))
