@@ -6,7 +6,6 @@ import numpy as np
 def tranform_data(mappingfile, mainsheet,stagingdata):
 
     # Read the file from given location
-    #file_path = "D:\BVB_Mapping_Kundenstamm.xlsx"
     xls = pa.ExcelFile(mappingfile)
 
     # to read all sheets to a map
@@ -22,7 +21,7 @@ def tranform_data(mappingfile, mainsheet,stagingdata):
             #
             if index >=9:
                 if row[33] and not row[33] is np.nan:
-                    row_dict[row[15]] = tb_row[row[33]]
+                    row_dict[row[15]] = str(tb_row[row[33]])
                 else:
                     if row[36] == 'tbl':
                         tab = {}
@@ -31,10 +30,10 @@ def tranform_data(mappingfile, mainsheet,stagingdata):
                                 tab[str(val[0])] = str(val[1])
                         if row[38] and not row[38] is np.nan:
                             if tb_row[row[38]] in tab:
-                                row_dict[row[15]] = tab[tb_row[row[38]]]
+                                row_dict[row[15]] = str(tab[tb_row[row[38]]])
                             else:
-                                row_dict[row[15]] = tb_row[row[38]]
+                                row_dict[row[15]] = str(tb_row[row[38]])
                     elif row[36] == 'const':
-                        row_dict[row[15]] = row[37]
+                        row_dict[row[15]] = str(row[37])
         rows_list.append(row_dict)
-    return pa.DataFrame(rows_list)
\ No newline at end of file
+    return pa.DataFrame(rows_list).replace('nan', '', regex=True)
\ No newline at end of file
